@@ -18,8 +18,13 @@ from pickle import PicklingError
 from threading import Thread
 from collections import defaultdict
 from concurrent import futures
-from concurrent.futures._base import (PENDING, RUNNING, CANCELLED,
-                                      CANCELLED_AND_NOTIFIED, FINISHED)
+from concurrent.futures._base import (
+    PENDING,
+    RUNNING,
+    CANCELLED,
+    CANCELLED_AND_NOTIFIED,
+    FINISHED,
+)
 
 import loky
 from loky.process_executor import (
@@ -70,7 +75,7 @@ def sleep_and_return(delay, x):
 
 def sleep_and_write(t, filename, msg):
     time.sleep(t)
-    with open(filename, 'w') as f:
+    with open(filename, "w") as f:
         f.write(str(msg))
 
 
@@ -98,7 +103,6 @@ def _assert_no_error(stderr):
 
 
 class ExecutorShutdownTest:
-
     def test_run_after_shutdown(self):
         self.executor.shutdown()
         with pytest.raises(RuntimeError):
@@ -120,7 +124,7 @@ class ExecutorShutdownTest:
 
         executor_type = self.executor_type.__name__
         start_method = self.context.get_start_method()
-        tempdir = tempfile.mkdtemp(prefix='loky_').replace("\\", "/")
+        tempdir = tempfile.mkdtemp(prefix="loky_").replace("\\", "/")
         try:
             n_jobs = 4
             code = f"""if True:
@@ -143,14 +147,16 @@ class ExecutorShutdownTest:
                 # processes finish in the background.
             """
             _, stderr = check_subprocess_call(
-                [sys.executable, "-c", code], timeout=55)
+                [sys.executable, "-c", code], timeout=55
+            )
 
             _assert_no_error(stderr)
 
             # The workers should have completed their work before the main
             # process exits:
-            expected_filenames = [f'task_{i:02d}.log'
-                                  for i in range(2 * n_jobs)]
+            expected_filenames = [
+                f"task_{i:02d}.log" for i in range(2 * n_jobs)
+            ]
 
             # Apparently files can take some time to appear under windows
             # on AppVeyor
@@ -163,7 +169,7 @@ class ExecutorShutdownTest:
 
             assert filenames == expected_filenames
             for i, filename in enumerate(filenames):
-                with open(os.path.join(tempdir, filename), 'rb') as f:
+                with open(os.path.join(tempdir, filename), "rb") as f:
                     assert int(f.read().strip()) == i
         finally:
             shutil.rmtree(tempdir)
@@ -187,8 +193,7 @@ class ExecutorShutdownTest:
 
     def test_processes_terminate_on_executor_gc(self):
 
-        results = self.executor.map(sleep_and_return,
-                                    [0.1] * 10, range(10))
+        results = self.executor.map(sleep_and_return, [0.1] * 10, range(10))
         assert len(self.executor._processes) == self.worker_count
         processes = self.executor._processes
         executor_flags = self.executor._flags
@@ -232,8 +237,7 @@ class ExecutorShutdownTest:
 
     def test_processes_crash_handling_after_executor_gc(self):
         # Start 5 easy jobs on 5 workers
-        results = self.executor.map(sleep_and_return,
-                                    [0.01] * 5, range(5))
+        results = self.executor.map(sleep_and_return, [0.01] * 5, range(5))
 
         # Enqueue a job that will trigger a crash of one of the workers.
         # Make sure this crash does not happen before the non-failing jobs
@@ -253,7 +257,7 @@ class ExecutorShutdownTest:
 
         if IS_PYPY:
             # Object deletion and garbage collection can be delayed under PyPy.
-            time.sleep(1.)
+            time.sleep(1.0)
             gc.collect()
 
         # Make sure that there is not other reference to the executor object.
@@ -285,8 +289,18 @@ class ExecutorShutdownTest:
     def test_context_manager_shutdown(self):
         with self.executor_type(max_workers=5, context=self.context) as e:
             processes = e._processes
-            assert list(e.map(abs, range(-5, 5))) == \
-                [5, 4, 3, 2, 1, 0, 1, 2, 3, 4]
+            assert list(e.map(abs, range(-5, 5))) == [
+                5,
+                4,
+                3,
+                2,
+                1,
+                0,
+                1,
+                2,
+                3,
+                4,
+            ]
 
         for p in processes.values():
             p.join()
@@ -299,7 +313,7 @@ class ExecutorShutdownTest:
         del executor
         if IS_PYPY:
             # Object deletion and garbage collection can be delayed under PyPy.
-            time.sleep(1.)
+            time.sleep(1.0)
             gc.collect()
 
         executor_manager_thread.join()
@@ -325,8 +339,10 @@ class ExecutorShutdownTest:
 
         # submit tasks that will finish after the shutdown and make sure they
         # were started
-        res = [self.executor.submit(self._wait_and_return, x)
-               for x in range(-5, 5)]
+        res = [
+            self.executor.submit(self._wait_and_return, x)
+            for x in range(-5, 5)
+        ]
 
         self.executor.shutdown(wait=False)
 
@@ -355,8 +371,9 @@ class ExecutorShutdownTest:
         # a deadlock if a task fails at pickle after the shutdown call.
         # Reported in bpo-39104.
         self.executor.shutdown(wait=True)
-        with self.executor_type(max_workers=2,
-                                context=self.context) as executor:
+        with self.executor_type(
+            max_workers=2, context=self.context
+        ) as executor:
             self.executor = executor  # Allow clean up in fail_on_deadlock
 
             # Start the executor and get the executor_manager_thread to collect
@@ -395,7 +412,8 @@ class ExecutorShutdownTest:
             e.shutdown(wait=False)
         """
         stdout, stderr = check_subprocess_call(
-            [sys.executable, "-c", code], timeout=55)
+            [sys.executable, "-c", code], timeout=55
+        )
 
         _assert_no_error(stderr)
         assert stdout.strip() == "apple"
@@ -403,9 +421,11 @@ class ExecutorShutdownTest:
     @classmethod
     def _test_shutdown_and_kill_workers(cls, depth):
         executor = cls.executor_type(
-            max_workers=2, context=cls.context,
+            max_workers=2,
+            context=cls.context,
             initializer=_executor_mixin.initializer_event,
-            initargs=(_executor_mixin._test_event,))
+            initargs=(_executor_mixin._test_event,),
+        )
         assert executor.submit(sleep_and_return, 0, 42).result() == 42
 
         if depth >= 2:
@@ -435,13 +455,14 @@ class ExecutorShutdownTest:
 
 
 class WaitTests:
-
     def test_first_completed(self):
         future1 = self.executor.submit(mul, 21, 2)
         future2 = self.executor.submit(time.sleep, 1.5)
 
-        done, not_done = futures.wait([CANCELLED_FUTURE, future1, future2],
-                                      return_when=futures.FIRST_COMPLETED)
+        done, not_done = futures.wait(
+            [CANCELLED_FUTURE, future1, future2],
+            return_when=futures.FIRST_COMPLETED,
+        )
 
         assert {future1} == done
         assert {CANCELLED_FUTURE, future2} == not_done
@@ -449,9 +470,10 @@ class WaitTests:
     def test_first_completed_some_already_completed(self):
         future1 = self.executor.submit(time.sleep, 1.5)
 
-        finished, pending = futures.wait([CANCELLED_AND_NOTIFIED_FUTURE,
-                                          SUCCESSFUL_FUTURE, future1],
-                                         return_when=futures.FIRST_COMPLETED)
+        finished, pending = futures.wait(
+            [CANCELLED_AND_NOTIFIED_FUTURE, SUCCESSFUL_FUTURE, future1],
+            return_when=futures.FIRST_COMPLETED,
+        )
 
         assert {CANCELLED_AND_NOTIFIED_FUTURE, SUCCESSFUL_FUTURE} == finished
         assert {future1} == pending
@@ -459,7 +481,7 @@ class WaitTests:
     @classmethod
     def wait_and_raise(cls, t):
         _executor_mixin._test_event.wait(t)
-        raise Exception('this is an exception')
+        raise Exception("this is an exception")
 
     @classmethod
     def wait_and_return(cls, t):
@@ -473,10 +495,12 @@ class WaitTests:
 
         def cb_done(f):
             _executor_mixin._test_event.set()
+
         future1.add_done_callback(cb_done)
 
-        finished, pending = futures.wait([future1, future2, future3],
-                                         return_when=futures.FIRST_EXCEPTION)
+        finished, pending = futures.wait(
+            [future1, future2, future3], return_when=futures.FIRST_EXCEPTION
+        )
 
         assert _executor_mixin._test_event.is_set()
 
@@ -489,22 +513,30 @@ class WaitTests:
         future1 = self.executor.submit(divmod, 21, 0)
         future2 = self.executor.submit(time.sleep, 1.5)
 
-        finished, pending = futures.wait([SUCCESSFUL_FUTURE, CANCELLED_FUTURE,
-                                          CANCELLED_AND_NOTIFIED_FUTURE,
-                                          future1, future2],
-                                         return_when=futures.FIRST_EXCEPTION)
-
-        assert (
-            {SUCCESSFUL_FUTURE, CANCELLED_AND_NOTIFIED_FUTURE, future1} ==
-            finished
+        finished, pending = futures.wait(
+            [
+                SUCCESSFUL_FUTURE,
+                CANCELLED_FUTURE,
+                CANCELLED_AND_NOTIFIED_FUTURE,
+                future1,
+                future2,
+            ],
+            return_when=futures.FIRST_EXCEPTION,
         )
+
+        assert {
+            SUCCESSFUL_FUTURE,
+            CANCELLED_AND_NOTIFIED_FUTURE,
+            future1,
+        } == finished
         assert {CANCELLED_FUTURE, future2} == pending
 
     def test_first_exception_one_already_failed(self):
         future1 = self.executor.submit(time.sleep, 2)
 
-        finished, pending = futures.wait([EXCEPTION_FUTURE, future1],
-                                         return_when=futures.FIRST_EXCEPTION)
+        finished, pending = futures.wait(
+            [EXCEPTION_FUTURE, future1], return_when=futures.FIRST_EXCEPTION
+        )
 
         assert {EXCEPTION_FUTURE} == finished
         assert {future1} == pending
@@ -513,13 +545,24 @@ class WaitTests:
         future1 = self.executor.submit(divmod, 2, 0)
         future2 = self.executor.submit(mul, 2, 21)
 
-        finished, pending = futures.wait([SUCCESSFUL_FUTURE, EXCEPTION_FUTURE,
-                                          CANCELLED_AND_NOTIFIED_FUTURE,
-                                          future1, future2],
-                                         return_when=futures.ALL_COMPLETED)
+        finished, pending = futures.wait(
+            [
+                SUCCESSFUL_FUTURE,
+                EXCEPTION_FUTURE,
+                CANCELLED_AND_NOTIFIED_FUTURE,
+                future1,
+                future2,
+            ],
+            return_when=futures.ALL_COMPLETED,
+        )
 
-        assert {SUCCESSFUL_FUTURE, CANCELLED_AND_NOTIFIED_FUTURE,
-                EXCEPTION_FUTURE, future1, future2} == finished
+        assert {
+            SUCCESSFUL_FUTURE,
+            CANCELLED_AND_NOTIFIED_FUTURE,
+            EXCEPTION_FUTURE,
+            future1,
+            future2,
+        } == finished
         assert not pending
 
     def test_timeout(self):
@@ -532,14 +575,24 @@ class WaitTests:
 
         assert future1.result() == 42
 
-        finished, pending = futures.wait([CANCELLED_AND_NOTIFIED_FUTURE,
-                                          EXCEPTION_FUTURE, SUCCESSFUL_FUTURE,
-                                          future1, future2],
-                                         timeout=.1,
-                                         return_when=futures.ALL_COMPLETED)
+        finished, pending = futures.wait(
+            [
+                CANCELLED_AND_NOTIFIED_FUTURE,
+                EXCEPTION_FUTURE,
+                SUCCESSFUL_FUTURE,
+                future1,
+                future2,
+            ],
+            timeout=0.1,
+            return_when=futures.ALL_COMPLETED,
+        )
 
-        assert {CANCELLED_AND_NOTIFIED_FUTURE, EXCEPTION_FUTURE,
-                SUCCESSFUL_FUTURE, future1} == finished
+        assert {
+            CANCELLED_AND_NOTIFIED_FUTURE,
+            EXCEPTION_FUTURE,
+            SUCCESSFUL_FUTURE,
+            future1,
+        } == finished
         assert {future2} == pending
 
         _executor_mixin._test_event.set()
@@ -553,32 +606,50 @@ class AsCompletedTests:
         future1 = self.executor.submit(mul, 2, 21)
         future2 = self.executor.submit(mul, 7, 6)
 
-        completed = set(futures.as_completed([CANCELLED_AND_NOTIFIED_FUTURE,
-                                              EXCEPTION_FUTURE,
-                                              SUCCESSFUL_FUTURE,
-                                              future1, future2]))
-        assert {CANCELLED_AND_NOTIFIED_FUTURE, EXCEPTION_FUTURE,
-                SUCCESSFUL_FUTURE, future1, future2} == completed
+        completed = set(
+            futures.as_completed(
+                [
+                    CANCELLED_AND_NOTIFIED_FUTURE,
+                    EXCEPTION_FUTURE,
+                    SUCCESSFUL_FUTURE,
+                    future1,
+                    future2,
+                ]
+            )
+        )
+        assert {
+            CANCELLED_AND_NOTIFIED_FUTURE,
+            EXCEPTION_FUTURE,
+            SUCCESSFUL_FUTURE,
+            future1,
+            future2,
+        } == completed
 
     def test_zero_timeout(self):
         future1 = self.executor.submit(time.sleep, 2)
         completed_futures = set()
         with pytest.raises(futures.TimeoutError):
             for future in futures.as_completed(
-                    [CANCELLED_AND_NOTIFIED_FUTURE,
-                     EXCEPTION_FUTURE,
-                     SUCCESSFUL_FUTURE,
-                     future1],
-                    timeout=0):
+                [
+                    CANCELLED_AND_NOTIFIED_FUTURE,
+                    EXCEPTION_FUTURE,
+                    SUCCESSFUL_FUTURE,
+                    future1,
+                ],
+                timeout=0,
+            ):
                 completed_futures.add(future)
 
-        assert {CANCELLED_AND_NOTIFIED_FUTURE, EXCEPTION_FUTURE,
-                SUCCESSFUL_FUTURE} == completed_futures
+        assert {
+            CANCELLED_AND_NOTIFIED_FUTURE,
+            EXCEPTION_FUTURE,
+            SUCCESSFUL_FUTURE,
+        } == completed_futures
 
     def test_duplicate_futures(self):
         # Issue 20367. Duplicate futures should not raise exceptions or give
         # duplicate responses.
-        future1 = self.executor.submit(time.sleep, .1)
+        future1 = self.executor.submit(time.sleep, 0.1)
         completed = list(futures.as_completed([future1, future1]))
         assert len(completed) == 1
 
@@ -595,13 +666,14 @@ class ExecutorTest:
         assert 16 == future.result()
 
     def test_map(self):
-        assert list(self.executor.map(pow, range(10), range(10))) == \
-            list(map(pow, range(10), range(10)))
+        assert list(self.executor.map(pow, range(10), range(10))) == list(
+            map(pow, range(10), range(10))
+        )
 
     def test_map_exception(self):
         i = self.executor.map(divmod, [1, 1, 1, 1], [2, 3, 0, 5])
-        assert next(i), (0 == 1)
-        assert next(i), (0 == 1)
+        assert next(i), 0 == 1
+        assert next(i), 0 == 1
         with pytest.raises(ZeroDivisionError):
             next(i)
 
@@ -621,9 +693,10 @@ class ExecutorTest:
         self.executor.shutdown()
 
     @pytest.mark.skipif(
-            platform.python_implementation() != "CPython" or
-            (sys.version_info >= (3, 8, 0) and sys.version_info < (3, 8, 2)),
-            reason="Underlying bug fixed upstream starting Python 3.8.2")
+        platform.python_implementation() != "CPython"
+        or (sys.version_info >= (3, 8, 0) and sys.version_info < (3, 8, 2)),
+        reason="Underlying bug fixed upstream starting Python 3.8.2",
+    )
     def test_no_stale_references(self):
         # Issue #16284: check that the executors don't unnecessarily hang onto
         # references.
@@ -675,12 +748,18 @@ class ExecutorTest:
             list(self.executor.map(pow, range(40), range(40), chunksize=-1))
 
         ref = list(map(pow, range(40), range(40)))
-        assert list(self.executor.map(pow, range(40), range(40), chunksize=6)
-                    ) == ref
-        assert list(self.executor.map(pow, range(40), range(40), chunksize=50)
-                    ) == ref
-        assert list(self.executor.map(pow, range(40), range(40), chunksize=40)
-                    ) == ref
+        assert (
+            list(self.executor.map(pow, range(40), range(40), chunksize=6))
+            == ref
+        )
+        assert (
+            list(self.executor.map(pow, range(40), range(40), chunksize=50))
+            == ref
+        )
+        assert (
+            list(self.executor.map(pow, range(40), range(40), chunksize=40))
+            == ref
+        )
         with pytest.raises(ValueError):
             bad_map()
 
@@ -701,14 +780,14 @@ class ExecutorTest:
 
         cause = exc.__cause__
         assert type(cause) is process_executor._RemoteTraceback
-        assert 'raise RuntimeError(123)  # some comment' in cause.tb
+        assert "raise RuntimeError(123)  # some comment" in cause.tb
 
     #
     # The following tests are new additions to the test suite originally
     # backported from the Python 3 concurrent.futures package.
     #
 
-    def _test_thread_safety(self, thread_idx, results, timeout=30.):
+    def _test_thread_safety(self, thread_idx, results, timeout=30.0):
         try:
             # submit a mix of very simple tasks with map and submit,
             # cancel some of them and check the results
@@ -717,8 +796,9 @@ class ExecutorTest:
                 # Make it more likely for scheduling threads to overtake one
                 # another
                 time.sleep(0.001)
-            submit_futures = [self.executor.submit(time.sleep, 0.0001)
-                              for _ in range(20)]
+            submit_futures = [
+                self.executor.submit(time.sleep, 0.0001) for _ in range(20)
+            ]
             for i, f in enumerate(submit_futures):
                 if i % 2 == 0:
                     f.cancel()
@@ -729,7 +809,7 @@ class ExecutorTest:
             for i, f in enumerate(submit_futures):
                 if i % 2 == 1 or not f.cancelled():
                     assert f.result(timeout=timeout) is None
-            results[thread_idx] = 'ok'
+            results[thread_idx] = "ok"
         except Exception as e:
             # Ensure that py.test can report the content of the exception
             # by raising it in the main test thread
@@ -739,8 +819,10 @@ class ExecutorTest:
         # Check that our process-pool executor can be shared to schedule work
         # by concurrent threads
         results = [None] * 10
-        threads = [Thread(target=self._test_thread_safety, args=(i, results))
-                   for i in range(len(results))]
+        threads = [
+            Thread(target=self._test_thread_safety, args=(i, results))
+            for i in range(len(results))
+        ]
 
         for t in threads:
             t.start()
@@ -767,22 +849,24 @@ class ExecutorTest:
                 future.add_done_callback(_collect_and_submit_next)
 
         # Start 3 concurrent callbacks chains
-        fa = executor.submit(self.return_inputs, 'chain a', 100)
+        fa = executor.submit(self.return_inputs, "chain a", 100)
         fa.add_done_callback(_collect_and_submit_next)
-        fb = executor.submit(self.return_inputs, 'chain b', 50)
+        fb = executor.submit(self.return_inputs, "chain b", 50)
         fb.add_done_callback(_collect_and_submit_next)
-        fc = executor.submit(self.return_inputs, 'chain c', 60)
+        fc = executor.submit(self.return_inputs, "chain c", 60)
         fc.add_done_callback(_collect_and_submit_next)
-        assert fa.result() == ('chain a', 100)
-        assert fb.result() == ('chain b', 50)
-        assert fc.result() == ('chain c', 60)
+        assert fa.result() == ("chain a", 100)
+        assert fb.result() == ("chain b", 50)
+        assert fc.result() == ("chain c", 60)
 
         # Wait a maximum of 5s for the asynchronous callback chains to complete
         patience = 500
         while True:
-            if (collected['chain a'] == list(range(100, -1, -1)) and
-                    collected['chain b'] == list(range(50, -1, -1)) and
-                    collected['chain c'] == list(range(60, -1, -1))):
+            if (
+                collected["chain a"] == list(range(100, -1, -1))
+                and collected["chain b"] == list(range(50, -1, -1))
+                and collected["chain c"] == list(range(60, -1, -1))
+            ):
                 # the recursive callback chains have completed successfully
                 break
             elif patience < 0:
@@ -797,10 +881,11 @@ class ExecutorTest:
     def test_worker_timeout(self):
         self.executor.shutdown(wait=True)
         self.check_no_running_workers(patience=5)
-        timeout = getattr(self, 'min_worker_timeout', .01)
+        timeout = getattr(self, "min_worker_timeout", 0.01)
         try:
             self.executor = self.executor_type(
-                max_workers=4, context=self.context, timeout=timeout)
+                max_workers=4, context=self.context, timeout=timeout
+            )
         except NotImplementedError as e:
             self.skipTest(str(e))
 
@@ -809,7 +894,7 @@ class ExecutorTest:
                 # It's ok to get a warning about the worker interrupted by the
                 # short timeout while tasks are pending in the queue on
                 # overloaded CI hosts.
-                warnings.simplefilter('ignore', category=UserWarning)
+                warnings.simplefilter("ignore", category=UserWarning)
 
                 # Trigger worker spawn for lazy executor implementations
                 for _ in self.executor.map(id, range(8)):
@@ -824,11 +909,11 @@ class ExecutorTest:
 
     @classmethod
     def reducer_in(cls, obj):
-        return MyObject, (obj.value + 5, )
+        return MyObject, (obj.value + 5,)
 
     @classmethod
     def reducer_out(cls, obj):
-        return MyObject, (7 * obj.value, )
+        return MyObject, (7 * obj.value,)
 
     def test_serialization(self):
         """Test custom serialization for process_executor"""
@@ -843,15 +928,18 @@ class ExecutorTest:
         # Create a new executor to ensure that we did not mess with the
         # existing module level serialization
         executor = self.executor_type(
-            max_workers=2, context=self.context, job_reducers=job_reducers,
-            result_reducers=result_reducers
+            max_workers=2,
+            context=self.context,
+            job_reducers=job_reducers,
+            result_reducers=result_reducers,
         )
         self.executor = self.executor_type(max_workers=2, context=self.context)
 
         obj = MyObject(1)
         try:
-            ret_obj_custom = executor.submit(
-                    self.return_inputs, obj).result()[0]
+            ret_obj_custom = executor.submit(self.return_inputs, obj).result()[
+                0
+            ]
             ret_obj = self.executor.submit(self.return_inputs, obj).result()[0]
 
             assert ret_obj.value == 1
@@ -870,45 +958,57 @@ class ExecutorTest:
         finally:
             executor.shutdown(wait=True, kill_workers=kill_workers)
 
-    @pytest.mark.parametrize('kill_workers', [True, False])
+    @pytest.mark.parametrize("kill_workers", [True, False])
     def test_max_depth(self, kill_workers):
         from loky.process_executor import MAX_DEPTH
-        if self.context.get_start_method() == 'fork':
+
+        if self.context.get_start_method() == "fork":
             # For 'fork', we do not allow nested process as the threads ends
             # up in messy states
             with pytest.raises(LokyRecursionError):
                 self._test_max_depth(max_depth=2, ctx=self.context)
             return
 
-        assert self._test_max_depth(max_depth=MAX_DEPTH,
-                                    kill_workers=kill_workers,
-                                    ctx=self.context) == 42
+        assert (
+            self._test_max_depth(
+                max_depth=MAX_DEPTH,
+                kill_workers=kill_workers,
+                ctx=self.context,
+            )
+            == 42
+        )
 
         with pytest.raises(LokyRecursionError):
-            self._test_max_depth(max_depth=MAX_DEPTH + 1,
-                                 kill_workers=kill_workers,
-                                 ctx=self.context)
+            self._test_max_depth(
+                max_depth=MAX_DEPTH + 1,
+                kill_workers=kill_workers,
+                ctx=self.context,
+            )
 
     @pytest.mark.high_memory
-    @pytest.mark.skipif(sys.maxsize < 2 ** 32,
-                        reason="Test requires a 64 bit version of Python")
+    @pytest.mark.skipif(
+        sys.maxsize < 2**32,
+        reason="Test requires a 64 bit version of Python",
+    )
     @pytest.mark.skipif(
         sys.version_info < (3, 8),
-        reason="Python version does not support pickling objects of size > 2 ** 31GB"
+        reason="Python version does not support pickling objects of size > 2 ** 31GB",
     )
     def test_no_failure_on_large_data_send(self):
-        data = b'\x00' * int(2.2e9)
+        data = b"\x00" * int(2.2e9)
         self.executor.submit(id, data).result()
 
     @pytest.mark.high_memory
-    @pytest.mark.skipif(sys.maxsize < 2 ** 32,
-                        reason="Test requires a 64 bit version of Python")
+    @pytest.mark.skipif(
+        sys.maxsize < 2**32,
+        reason="Test requires a 64 bit version of Python",
+    )
     @pytest.mark.skipif(
         sys.version_info >= (3, 8),
-        reason="Python version supports pickling objects of size > 2 ** 31GB"
+        reason="Python version supports pickling objects of size > 2 ** 31GB",
     )
     def test_expected_failure_on_large_data_send(self):
-        data = b'\x00' * int(2.2e9)
+        data = b"\x00" * int(2.2e9)
         with pytest.raises(RuntimeError):
             self.executor.submit(id, data).result()
 
@@ -919,10 +1019,11 @@ class ExecutorTest:
         executor = self.executor_type(1, context=self.context)
 
         def _leak_some_memory(size=int(3e6), delay=0.001):
-            """function that leaks some memory """
+            """function that leaks some memory"""
             from loky import process_executor
+
             process_executor._MEMORY_LEAK_CHECK_DELAY = 0.1
-            if getattr(os, '_loky_leak', None) is None:
+            if getattr(os, "_loky_leak", None) is None:
                 os._loky_leak = []
 
             os._loky_leak.append(b"\x00" * size)
@@ -935,7 +1036,7 @@ class ExecutorTest:
             leaked_size = sum(len(buffer) for buffer in os._loky_leak)
             return os.getpid(), leaked_size
 
-        with pytest.warns(UserWarning, match='memory leak'):
+        with pytest.warns(UserWarning, match="memory leak"):
             # Total run time should be 3s which is way over the 1s cooldown
             # period between two consecutive memory checks in the worker.
             futures = [executor.submit(_leak_some_memory) for _ in range(300)]
@@ -963,6 +1064,7 @@ class ExecutorTest:
         def _create_cyclic_reference(delay=0.001):
             """function that creates a cyclic reference"""
             from loky import process_executor
+
             process_executor._USE_PSUTIL = False
             process_executor._MEMORY_LEAK_CHECK_DELAY = 0.1
 
@@ -970,7 +1072,8 @@ class ExecutorTest:
                 def __init__(self, size=int(1e6)):
                     self.data = b"\x00" * size
                     self.a = self
-            if getattr(os, '_loky_cyclic_weakrefs', None) is None:
+
+            if getattr(os, "_loky_cyclic_weakrefs", None) is None:
                 os._loky_cyclic_weakrefs = []
 
             a = A()
@@ -1010,7 +1113,7 @@ class ExecutorTest:
     def test_child_env_executor(self):
         # Test that for loky context, setting argument env correctly overwrite
         # the environment of the child process.
-        if self.context.get_start_method() != 'loky':
+        if self.context.get_start_method() != "loky":
             pytest.skip("Only work with loky context")
 
         var_name = "loky_child_env_executor"
@@ -1075,9 +1178,7 @@ class ExecutorTest:
         try:
             tracer.start()
             with self.executor_type(
-                1,
-                context=self.context,
-                initializer=_custom_initializer
+                1, context=self.context, initializer=_custom_initializer
             ) as e:
                 assert e.submit(
                     check_viztracer_active_and_custom_init
@@ -1085,6 +1186,26 @@ class ExecutorTest:
         finally:
             tracer.stop()
 
+    def test_exception_cause_with_tblib(self):
+        "Ensure tampering with exception pickling do not break __cause__ propagation"
+        tblib_pickling_support = pytest.importorskip("tblib.pickling_support")
+
+        error_message = "This is the error message"
+
+        def raise_value_error():
+            tblib_pickling_support.install()
+            raise ValueError(error_message)
+
+        executor = self.executor_type(max_workers=2)
+        f = executor.submit(raise_value_error)
+        try:
+            f.result()
+        except ValueError as e:
+            assert e.__cause__ is not None
+            assert error_message in str(e.__cause__)
+
+        executor.shutdown(wait=True)
+
 
 def _custom_initializer():
     """_custom_initializer is module function to be picklable
