@@ -20,6 +20,7 @@ from loky import get_reusable_executor
 from loky.process_executor import _RemoteTraceback, TerminatedWorkerError
 from loky.process_executor import BrokenProcessPool, ShutdownExecutorError
 from loky.reusable_executor import _ReusablePoolExecutor
+from loky.backend.context import _MAX_WINDOWS_WORKERS
 
 try:
     import psutil
@@ -35,10 +36,12 @@ cloudpickle_version = Version(cloudpickle.__version__)
 # Compat windows
 if sys.platform == "win32":
     from signal import SIGTERM as SIGKILL
+
     libc = ctypes.cdll.msvcrt
 else:
     from signal import SIGKILL
     from ctypes.util import find_library
+
     libc = ctypes.CDLL(find_library("c"))
 
 
@@ -51,10 +54,11 @@ except ImportError:
 def clean_warning_registry():
     """Safe way to reset warnings."""
     warnings.resetwarnings()
-    reg = "__warningregistry__"
+    registry_name = "__warningregistry__"
     for mod in list(sys.modules.values()):
-        if hasattr(mod, reg):
-            getattr(mod, reg).clear()
+        warning_registry = getattr(mod, registry_name, None)
+        if warning_registry is not None:
+            warning_registry.clear()
 
 
 def wait_dead(worker, n_tries=1000, delay=0.001):
@@ -72,6 +76,7 @@ def wait_dead(worker, n_tries=1000, delay=0.001):
 def crash():
     """Induces a segfault"""
     import faulthandler
+
     faulthandler._sigsegv()
 
 
@@ -135,42 +140,49 @@ def do_nothing(arg):
 
 class CrashAtPickle:
     """Bad object that triggers a segfault at pickling time."""
+
     def __reduce__(self):
         crash()
 
 
 class CrashAtUnpickle:
     """Bad object that triggers a segfault at unpickling time."""
+
     def __reduce__(self):
         return crash, ()
 
 
 class ExitAtPickle:
     """Bad object that triggers a segfault at pickling time."""
+
     def __reduce__(self):
         exit()
 
 
 class ExitAtUnpickle:
     """Bad object that triggers a process exit at unpickling time."""
+
     def __reduce__(self):
         return exit, ()
 
 
 class CExitAtPickle:
     """Bad object that triggers a segfault at pickling time."""
+
     def __reduce__(self):
         c_exit()
 
 
 class CExitAtUnpickle:
     """Bad object that triggers a process exit at unpickling time."""
+
     def __reduce__(self):
         return c_exit, ()
 
 
 class ErrorAtPickle:
     """Bad object that raises an error at pickling time."""
+
     def __init__(self, fail=True):
         self.fail = fail
 
@@ -178,12 +190,13 @@ class ErrorAtPickle:
         if self.fail:
             raise PicklingError("Error in pickle")
         else:
-            return id, (42, )
+            return id, (42,)
 
 
 class ErrorAtUnpickle:
     """Bad object that triggers a process exit at unpickling time."""
-    def __init__(self, etype=UnpicklingError, message='the error message'):
+
+    def __init__(self, etype=UnpicklingError, message="the error message"):
         self.etype = etype
         self.message = message
 
@@ -193,6 +206,7 @@ class ErrorAtUnpickle:
 
 class CrashAtGCInWorker:
     """Bad object that triggers a segfault at call item GC time"""
+
     def __del__(self):
         if current_process().name != "MainProcess":
             crash()
@@ -200,13 +214,13 @@ class CrashAtGCInWorker:
 
 class CExitAtGCInWorker:
     """Exit worker at call item GC time"""
+
     def __del__(self):
         if current_process().name != "MainProcess":
             c_exit()
 
 
 class TestExecutorDeadLock(ReusableExecutorMixin):
-
     crash_cases = [
         # Check problem occuring while pickling a task in
         (id, (ExitAtPickle(),), PicklingError, None),
@@ -225,14 +239,22 @@ class TestExecutorDeadLock(ReusableExecutorMixin):
         # on workers
         (return_instance, (CrashAtPickle,), TerminatedWorkerError, "SIGSEGV"),
         (return_instance, (ExitAtPickle,), SystemExit, None),
-        (return_instance, (CExitAtPickle,), TerminatedWorkerError,
-         r"EXIT\(0\)"),
+        (
+            return_instance,
+            (CExitAtPickle,),
+            TerminatedWorkerError,
+            r"EXIT\(0\)",
+        ),
         (return_instance, (ErrorAtPickle,), PicklingError, None),
         # Check problem occuring while unpickling a task in
         # the result_handler thread
         (return_instance, (ExitAtUnpickle,), BrokenProcessPool, "SystemExit"),
-        (return_instance, (ErrorAtUnpickle,), BrokenProcessPool,
-         "UnpicklingError"),
+        (
+            return_instance,
+            (ErrorAtUnpickle,),
+            BrokenProcessPool,
+            "UnpicklingError",
+        ),
     ]
 
     @pytest.mark.parametrize("func, args, expected_err, match", crash_cases)
@@ -255,14 +277,16 @@ class TestExecutorDeadLock(ReusableExecutorMixin):
                 raise exc_info.value.__cause__
 
     @pytest.mark.parametrize("func, args, expected_err, match", crash_cases)
-    def test_in_callback_submit_with_crash(self, func, args, expected_err,
-                                           match):
+    def test_in_callback_submit_with_crash(
+        self, func, args, expected_err, match
+    ):
         """Test the recovery from callback crash"""
         executor = get_reusable_executor(max_workers=2, timeout=12)
 
         def in_callback_submit(future):
-            future2 = get_reusable_executor(
-                max_workers=2, timeout=12).submit(func, *args)
+            future2 = get_reusable_executor(max_workers=2, timeout=12).submit(
+                func, *args
+            )
             # Store the future of the job submitted in the callback to make it
             # easy to introspect.
             future.callback_future = future2
@@ -277,7 +301,7 @@ class TestExecutorDeadLock(ReusableExecutorMixin):
         f.add_done_callback(in_callback_submit)
         assert f.result() == 42
         if not f.callback_done.wait(timeout=3):
-            raise AssertionError('callback not done before timeout')
+            raise AssertionError("callback not done before timeout")
 
         match_err = None
         if expected_err is TerminatedWorkerError:
@@ -314,7 +338,7 @@ class TestExecutorDeadLock(ReusableExecutorMixin):
         f = executor.submit(id_sleep, 42, delay)
         f.add_done_callback(lambda _: raise_error())
         assert f.result() == 42
-        assert executor.submit(id_sleep, 42, 0.).result() == 42
+        assert executor.submit(id_sleep, 42, 0.0).result() == 42
 
     def test_deadlock_kill(self):
         """Test deadlock recovery for reusable_executor"""
@@ -325,31 +349,37 @@ class TestExecutorDeadLock(ReusableExecutorMixin):
         with pytest.warns(UserWarning) as recorded_warnings:
             executor = get_reusable_executor(max_workers=2, timeout=None)
         assert len(recorded_warnings) == 1
-        expected_msg = ("Trying to resize an executor with running jobs:"
-                        " waiting for jobs completion before resizing.")
+        expected_msg = (
+            "Trying to resize an executor with running jobs:"
+            " waiting for jobs completion before resizing."
+        )
         assert recorded_warnings[0].message.args[0] == expected_msg
         os.kill(worker.pid, SIGKILL)
         wait_dead(worker)
 
         # wait for the executor to be able to detect the issue and set itself
         # in broken state:
-        sleep(.5)
-        with pytest.raises(TerminatedWorkerError,
-                           match=filter_match("SIGKILL")):
+        sleep(0.5)
+        with pytest.raises(
+            TerminatedWorkerError, match=filter_match("SIGKILL")
+        ):
             executor.submit(id_sleep, 42, 0.1).result()
 
         # the get_reusable_executor factory should be able to create a new
         # working instance
         executor = get_reusable_executor(max_workers=2, timeout=None)
-        assert executor.submit(id_sleep, 42, 0.).result() == 42
+        assert executor.submit(id_sleep, 42, 0.0).result() == 42
 
     @pytest.mark.parametrize("n_proc", [1, 2, 5, 13])
     def test_crash_races(self, n_proc):
         """Test the race conditions in reusable_executor crash handling"""
         pytest.importorskip("psutil")  # required for kill_friend & co
 
-        if (sys.platform == 'win32' and sys.version_info >= (3, 8)
-                and n_proc > 5):
+        if (
+            sys.platform == "win32"
+            and sys.version_info >= (3, 8)
+            and n_proc > 5
+        ):
             pytest.skip(
                 "On win32, the paging size can be too small to import numpy "
                 "multiple times in the sub-processes (imported when loading "
@@ -364,12 +394,14 @@ class TestExecutorDeadLock(ReusableExecutorMixin):
         pids = list(executor._processes.keys())
         assert len(pids) == n_proc
         assert None not in pids
-        res = executor.map(sleep_then_check_pids_exist,
-                           [(.0001 * (j // 2), pids)
-                            for j in range(2 * n_proc)])
+        res = executor.map(
+            sleep_then_check_pids_exist,
+            [(0.0001 * (j // 2), pids) for j in range(2 * n_proc)],
+        )
         assert all(res)
-        with pytest.raises(TerminatedWorkerError,
-                           match=filter_match("SIGKILL")):
+        with pytest.raises(
+            TerminatedWorkerError, match=filter_match("SIGKILL")
+        ):
             res = executor.map(kill_friend, pids[::-1])
             list(res)
 
@@ -378,19 +410,22 @@ class TestExecutorDeadLock(ReusableExecutorMixin):
         # builded version of python
         executor = get_reusable_executor(max_workers=2)
         with pytest.raises(SayWhenError):
-            executor.map(id_sleep, exception_throwing_generator(10, 3),
-                         chunksize=1)
+            executor.map(
+                id_sleep, exception_throwing_generator(10, 3), chunksize=1
+            )
 
         # SayWhenError seen at start of problematic chunk's results
         executor = get_reusable_executor(max_workers=2)
         with pytest.raises(SayWhenError):
-            executor.map(id_sleep, exception_throwing_generator(20, 7),
-                         chunksize=2)
+            executor.map(
+                id_sleep, exception_throwing_generator(20, 7), chunksize=2
+            )
 
         executor = get_reusable_executor(max_workers=2)
         with pytest.raises(SayWhenError):
-            executor.map(id_sleep, exception_throwing_generator(20, 7),
-                         chunksize=4)
+            executor.map(
+                id_sleep, exception_throwing_generator(20, 7), chunksize=4
+            )
 
     def test_queue_full_deadlock(self):
         with warnings.catch_warnings():
@@ -399,23 +434,27 @@ class TestExecutorDeadLock(ReusableExecutorMixin):
             executor = get_reusable_executor(max_workers=1)
             executor.submit(id, 42)
 
-        fs_fail = [executor.submit(do_nothing, ErrorAtPickle(True))
-                   for _ in range(100)]
-        fs = [executor.submit(do_nothing, ErrorAtPickle(False))
-              for _ in range(100)]
+        fs_fail = [
+            executor.submit(do_nothing, ErrorAtPickle(True))
+            for _ in range(100)
+        ]
+        fs = [
+            executor.submit(do_nothing, ErrorAtPickle(False))
+            for _ in range(100)
+        ]
         with pytest.raises(PicklingError):
             fs_fail[99].result()
         assert fs[99].result()
 
     def test_informative_error_when_fail_at_unpickle(self):
         executor = get_reusable_executor(max_workers=2)
-        obj = ErrorAtUnpickle(RuntimeError, 'message raised in child')
+        obj = ErrorAtUnpickle(RuntimeError, "message raised in child")
         f = executor.submit(id, obj)
 
         with pytest.raises(BrokenProcessPool) as exc_info:
             f.result()
-        assert 'RuntimeError' in str(exc_info.value.__cause__)
-        assert 'message raised in child' in str(exc_info.value.__cause__)
+        assert "RuntimeError" in str(exc_info.value.__cause__)
+        assert "message raised in child" in str(exc_info.value.__cause__)
 
     @pytest.mark.skipif(np is None, reason="requires numpy")
     def test_numpy_dot_parent_and_child_no_freeze(self):
@@ -430,12 +469,12 @@ class TestExecutorDeadLock(ReusableExecutorMixin):
 
 
 class TestTerminateExecutor(ReusableExecutorMixin):
-
     def test_shutdown_kill(self):
         """Test reusable_executor termination handling"""
         from itertools import repeat
+
         executor = get_reusable_executor(max_workers=5)
-        res1 = executor.map(id_sleep, range(100), repeat(.001))
+        res1 = executor.map(id_sleep, range(100), repeat(0.001))
         res2 = executor.map(id_sleep, range(100), repeat(1))
         assert list(res1) == list(range(100))
 
@@ -455,9 +494,10 @@ class TestTerminateExecutor(ReusableExecutorMixin):
         # Test the executor.shutdown call do not cause deadlock
         executor = get_reusable_executor(max_workers=2, timeout=None)
         executor.map(id, range(2))  # start the worker processes
-        executor.submit(kill_friend, (next(iter(executor._processes.keys())),
-                                      .0))
-        sleep(.01)
+        executor.submit(
+            kill_friend, (next(iter(executor._processes.keys())), 0.0)
+        )
+        sleep(0.01)
         executor.shutdown(wait=True)
 
     def test_kill_workers_on_new_options(self):
@@ -468,15 +508,18 @@ class TestTerminateExecutor(ReusableExecutorMixin):
         # change the constructor parameter while requesting not to wait
         # for the long running task to complete (the workers will get
         # shutdown forcibly)
-        executor = get_reusable_executor(max_workers=2, timeout=5,
-                                         kill_workers=True)
+        executor = get_reusable_executor(
+            max_workers=2, timeout=5, kill_workers=True
+        )
         with pytest.raises(ShutdownExecutorError):
             f.result()
         f2 = executor.submit(id_sleep, 42, 0)
         assert f2.result() == 42
 
-    @pytest.mark.parametrize("bad_object, match", [
-        (CrashAtGCInWorker, "SIGSEGV"), (CExitAtGCInWorker, r"EXIT\(0\)")])
+    @pytest.mark.parametrize(
+        "bad_object, match",
+        [(CrashAtGCInWorker, "SIGSEGV"), (CExitAtGCInWorker, r"EXIT\(0\)")],
+    )
     def test_call_item_gc_crash_or_exit(self, bad_object, match):
         executor = get_reusable_executor(max_workers=1)
         bad_object = bad_object()
@@ -490,7 +533,7 @@ class TestTerminateExecutor(ReusableExecutorMixin):
         # when processing subsequently dispatched tasks:
         with pytest.raises(TerminatedWorkerError, match=filter_match(match)):
             executor.submit(gc.collect).result()
-            for _ in executor.map(sleep, [.1] * 100):
+            for _ in executor.map(sleep, [0.1] * 100):
                 pass
 
     def test_sigkill_shutdown_leaks_workers(self):
@@ -510,8 +553,9 @@ class TestTerminateExecutor(ReusableExecutorMixin):
             print(f'parent_pid:{parent_pid}')
             psutil.Process(os.getpid()).kill()
         """
-        with NamedTemporaryFile(mode='w', suffix="_joblib.py",
-                                delete=True) as f:
+        with NamedTemporaryFile(
+            mode="w", suffix="_joblib.py", delete=True
+        ) as f:
             f.write(code)
             f.flush()
             cmd = [sys.executable, f.name]
@@ -520,19 +564,20 @@ class TestTerminateExecutor(ReusableExecutorMixin):
                 stdout=subprocess.PIPE,
                 stderr=subprocess.STDOUT,
                 text=True,
-                timeout=60
+                timeout=60,
             )
             running_workers = []
-            for line in out.stdout.split('\n'):
-                if line.startswith('worker_pid'):
-                    worker_pid = int(line.split(':')[1])
+            for line in out.stdout.split("\n"):
+                if line.startswith("worker_pid"):
+                    worker_pid = int(line.split(":")[1])
                     try:
                         psutil.Process(worker_pid)
                         running_workers.append(worker_pid)
                     except psutil.NoSuchProcess:
                         pass
-            assert not len(running_workers), (
-                f'There are running workers left: {running_workers}')
+            assert not len(
+                running_workers
+            ), f"There are running workers left: {running_workers}"
 
 
 class TestResizeExecutor(ReusableExecutorMixin):
@@ -548,7 +593,7 @@ class TestResizeExecutor(ReusableExecutorMixin):
         # the old one as it is still in a good shape. The resize should not
         # occur while there are on going works.
         pids = list(executor._processes.keys())
-        res1 = executor.submit(sleep_then_check_pids_exist, (.3, pids))
+        res1 = executor.submit(sleep_then_check_pids_exist, (0.3, pids))
         clean_warning_registry()
         with warnings.catch_warnings(record=True) as w:
             # Cause all warnings to always be triggered.
@@ -557,8 +602,9 @@ class TestResizeExecutor(ReusableExecutorMixin):
             assert len(w) == 1
             expected_msg = "Trying to resize an executor with running jobs"
             assert expected_msg in str(w[0].message)
-            assert res1.result(), ("Resize should wait for current processes "
-                                   " to finish")
+            assert res1.result(), (
+                "Resize should wait for current processes " " to finish"
+            )
             assert len(executor._processes) == 1
             assert next(iter(executor._processes.keys())) in pids
 
@@ -582,9 +628,9 @@ class TestResizeExecutor(ReusableExecutorMixin):
         # Tentative non-regression test for a deadlock when shutting down
         # the workers of an executor prior to resizing it.
         kwargs = {
-            'timeout': None,
-            'kill_workers': kill_workers,
-            'reuse': reuse,
+            "timeout": None,
+            "kill_workers": kill_workers,
+            "reuse": reuse,
         }
         with warnings.catch_warnings(record=True):
             # Cause all warnings to always be triggered.
@@ -603,37 +649,38 @@ class TestResizeExecutor(ReusableExecutorMixin):
         executor = get_reusable_executor(max_workers=2, timeout=None)
         executor.map(id, range(2))  # trigger the creation of worker processes
         pid = next(iter(executor._processes.keys()))
-        executor.submit(kill_friend, (pid, .1))
+        executor.submit(kill_friend, (pid, 0.1))
 
         with pytest.warns(UserWarning) as recorded_warnings:
             warnings.simplefilter("always")
             executor = get_reusable_executor(max_workers=1, timeout=None)
         assert len(recorded_warnings) == 1
-        expected_msg = ("Trying to resize an executor with running jobs:"
-                        " waiting for jobs completion before resizing.")
+        expected_msg = (
+            "Trying to resize an executor with running jobs:"
+            " waiting for jobs completion before resizing."
+        )
         assert recorded_warnings[0].message.args[0] == expected_msg
-        assert executor.submit(id_sleep, 42, 0.).result() == 42
+        assert executor.submit(id_sleep, 42, 0.0).result() == 42
         executor.shutdown()
 
     def test_resize_after_timeout(self):
         with warnings.catch_warnings(record=True) as recorded_warnings:
             warnings.simplefilter("always")
-            executor = get_reusable_executor(max_workers=2, timeout=.001)
-            assert executor.submit(id_sleep, 42, 0.).result() == 42
-            sleep(.1)
-            executor = get_reusable_executor(max_workers=8, timeout=.001)
-            assert executor.submit(id_sleep, 42, 0.).result() == 42
-            sleep(.1)
-            executor = get_reusable_executor(max_workers=2, timeout=.001)
-            assert executor.submit(id_sleep, 42, 0.).result() == 42
+            executor = get_reusable_executor(max_workers=2, timeout=0.001)
+            assert executor.submit(id_sleep, 42, 0.0).result() == 42
+            sleep(0.1)
+            executor = get_reusable_executor(max_workers=8, timeout=0.001)
+            assert executor.submit(id_sleep, 42, 0.0).result() == 42
+            sleep(0.1)
+            executor = get_reusable_executor(max_workers=2, timeout=0.001)
+            assert executor.submit(id_sleep, 42, 0.0).result() == 42
 
         if len(recorded_warnings) > 1:
-            expected_msg = 'A worker stopped'
+            expected_msg = "A worker stopped"
             assert expected_msg in recorded_warnings[0].message.args[0]
 
 
 class TestGetReusableExecutor(ReusableExecutorMixin):
-
     def test_invalid_process_number(self):
         """Raise error on invalid process number"""
 
@@ -656,11 +703,11 @@ class TestGetReusableExecutor(ReusableExecutorMixin):
                 get_reusable_executor(max_workers=2, context="fork")
 
     def test_pass_start_method_name_as_context(self):
-        executor = get_reusable_executor(max_workers=2, context='loky')
+        executor = get_reusable_executor(max_workers=2, context="loky")
         assert executor.submit(id, 42).result() >= 0
 
         with pytest.raises(ValueError):
-            get_reusable_executor(max_workers=2, context='bad_start_method')
+            get_reusable_executor(max_workers=2, context="bad_start_method")
 
     def test_interactively_defined_executor_no_main(self):
         # check that the init_main_module parameter works properly
@@ -690,9 +737,11 @@ class TestGetReusableExecutor(ReusableExecutorMixin):
         )
         assert not reused
 
-    @pytest.mark.xfail(cloudpickle_version >= Version("0.5.4") and
-                       cloudpickle_version <= Version("0.7.0"),
-                       reason="Known issue in cloudpickle")
+    @pytest.mark.xfail(
+        cloudpickle_version >= Version("0.5.4")
+        and cloudpickle_version <= Version("0.7.0"),
+        reason="Known issue in cloudpickle",
+    )
     # https://github.com/cloudpipe/cloudpickle/pull/240
     def test_interactively_defined_nested_functions(self):
         # Check that it's possible to call nested interactively defined
@@ -807,7 +856,7 @@ class TestGetReusableExecutor(ReusableExecutorMixin):
         # It should be possible to use a loky process pool executor as a dropin
         # replacement for a ProcessPoolExecutor, including when catching
         # exceptions:
-        concurrent = pytest.importorskip('concurrent')
+        concurrent = pytest.importorskip("concurrent")
         from concurrent.futures.process import BrokenProcessPool as BPPExc
 
         with pytest.raises(BPPExc):
@@ -822,55 +871,62 @@ class TestGetReusableExecutor(ReusableExecutorMixin):
         assert len(running) == 0
 
     thread_configurations = [
-        ('constant', 'clean_start'),
-        ('constant', 'broken_start'),
-        ('varying', 'clean_start'),
-        ('varying', 'broken_start'),
+        ("constant", "clean_start"),
+        ("constant", "broken_start"),
+        ("varying", "clean_start"),
+        ("varying", "broken_start"),
     ]
 
     @pytest.mark.parametrize("workers, executor_state", thread_configurations)
     def test_reusable_executor_thread_safety(self, workers, executor_state):
-        if executor_state == 'clean_start':
+        if executor_state == "clean_start":
             # Create a new shared executor and ensures that it's workers are
             # ready:
             get_reusable_executor(reuse=False).submit(id, 42).result()
         else:
             # Break the shared executor before launching the threads:
-            with pytest.raises(TerminatedWorkerError,
-                               match=filter_match("SIGSEGV")):
+            with pytest.raises(
+                TerminatedWorkerError, match=filter_match("SIGSEGV")
+            ):
                 executor = get_reusable_executor(reuse=False)
                 executor.submit(return_instance, CrashAtPickle).result()
 
-        def helper_func(output_collector, max_workers=2, n_outer_steps=5,
-                        n_inner_steps=10):
+        def helper_func(
+            output_collector, max_workers=2, n_outer_steps=5, n_inner_steps=10
+        ):
             with warnings.catch_warnings():  # ignore resize warnings
                 warnings.simplefilter("always")
                 executor = get_reusable_executor(max_workers=max_workers)
                 for _ in range(n_outer_steps):
                     results = executor.map(
-                        lambda x: x ** 2, range(n_inner_steps))
-                    expected_result = [x ** 2 for x in range(n_inner_steps)]
+                        lambda x: x**2, range(n_inner_steps)
+                    )
+                    expected_result = [x**2 for x in range(n_inner_steps)]
                     assert list(results) == expected_result
-                output_collector.append('ok')
+                output_collector.append("ok")
 
-        if workers == 'constant':
+        if workers == "constant":
             max_workers = [2] * 10
         else:
             max_workers = [(i % 4) + 1 for i in range(10)]
         # Use the same executor with the same number of workers concurrently
         # in different threads:
         output_collector = []
-        threads = [threading.Thread(
-            target=helper_func, args=(output_collector, w),
-            name=f'test_thread_{i:02d}_max_workers_{w:d}')
-            for i, w in enumerate(max_workers)]
+        threads = [
+            threading.Thread(
+                target=helper_func,
+                args=(output_collector, w),
+                name=f"test_thread_{i:02d}_max_workers_{w:d}",
+            )
+            for i, w in enumerate(max_workers)
+        ]
 
         with warnings.catch_warnings(record=True):
             for t in threads:
                 t.start()
             for t in threads:
                 t.join()
-        assert output_collector == ['ok'] * len(threads)
+        assert output_collector == ["ok"] * len(threads)
 
     def test_reusable_executor_reuse_true(self):
         executor = get_reusable_executor(max_workers=3, timeout=42)
@@ -904,25 +960,27 @@ class TestExecutorInitializer(ReusableExecutorMixin):
 
     def test_reusable_initializer(self):
         executor = get_reusable_executor(
-            max_workers=2, initializer=self._initializer, initargs=('done',))
+            max_workers=2, initializer=self._initializer, initargs=("done",)
+        )
 
-        assert executor.submit(self._test_initializer).result() == 'done'
+        assert executor.submit(self._test_initializer).result() == "done"
 
         # when the initializer change, the executor is re-spawned
         executor = get_reusable_executor(
-            max_workers=2, initializer=self._initializer, initargs=(42,))
+            max_workers=2, initializer=self._initializer, initargs=(42,)
+        )
 
         assert executor.submit(self._test_initializer).result() == 42
 
         # With reuse=True, the executor use the same initializer
         executor = get_reusable_executor(max_workers=4, reuse=True)
-        for x in executor.map(self._test_initializer, delay=.1):
+        for x in executor.map(self._test_initializer, delay=0.1):
             assert x == 42
 
         # With reuse='auto', the initializer is not used anymore
         executor = get_reusable_executor(max_workers=4)
-        for x in executor.map(self._test_initializer, delay=.1):
-            assert x == 'uninitialized'
+        for x in executor.map(self._test_initializer, delay=0.1):
+            assert x == "uninitialized"
 
     # XXX: not sure if #369 has been fixed or not. Let's not make it XFAIL
     # for now to see if it is still flaky on CI.
@@ -930,7 +988,7 @@ class TestExecutorInitializer(ReusableExecutorMixin):
     def test_error_in_nested_call_keeps_resource_tracker_silent(self):
         # Safety smoke test: test that nested parallel calls don't yield noisy
         # resource_tracker outputs when the grandchild errors out.
-        cmd = '''if 1:
+        cmd = """if 1:
             from loky import get_reusable_executor
 
 
@@ -945,10 +1003,57 @@ class TestExecutorInitializer(ReusableExecutorMixin):
 
             executor = get_reusable_executor(max_workers=2)
             list(executor.map(nested_loop, [raise_error])
-        '''
-        p = subprocess.Popen([sys.executable, '-c', cmd],
-                            stderr=subprocess.PIPE, stdout=subprocess.PIPE)
+        """
+        p = subprocess.Popen(
+            [sys.executable, "-c", cmd],
+            stderr=subprocess.PIPE,
+            stdout=subprocess.PIPE,
+        )
         p.wait()
         out, err = p.communicate()
         assert p.returncode == 1, out.decode()
         assert b"resource_tracker" not in err, err.decode()
+
+
+def test_no_crash_max_workers_on_windows():
+    # Check that loky's reusable process pool executor does not crash when the
+    # user asks for more workers than the maximum number of workers supported
+    # by the platform.
+
+    # To make sure we have the proper size for the call_queue, we
+    # shutdown the existing executor.
+    # See https://github.com/joblib/loky#396
+    get_reusable_executor().shutdown()
+
+    # Note: on overloaded CI hosts, spawning many processes can take a long
+    # time. We need to increase the timeout to avoid spurious failures when
+    # making assertions on `len(executor._processes)`.
+    idle_worker_timeout = 5 * 60
+    with warnings.catch_warnings(record=True) as record:
+        executor = get_reusable_executor(
+            max_workers=_MAX_WINDOWS_WORKERS + 1,
+            timeout=idle_worker_timeout,
+        )
+        assert executor.submit(lambda: None).result() is None
+    if sys.platform == "win32":
+        assert len(record) == 1
+        assert "max_workers" in str(record[0].message)
+        assert len(executor._processes) == _MAX_WINDOWS_WORKERS
+    else:
+        assert len(record) == 0
+        assert len(executor._processes) == _MAX_WINDOWS_WORKERS + 1
+
+    # Downsizing should never raise a warning.
+    before_downsizing_executor = executor
+    with warnings.catch_warnings(record=True) as record:
+        executor = get_reusable_executor(
+            max_workers=_MAX_WINDOWS_WORKERS, timeout=idle_worker_timeout
+        )
+        assert executor.submit(lambda: None).result() is None
+
+    # No warning on any OS when max_workers does not exceed the limit.
+    assert len(record) == 0
+    assert before_downsizing_executor is executor
+    assert len(executor._processes) == _MAX_WINDOWS_WORKERS
+
+    executor.shutdown()
